@@ -6,7 +6,7 @@ import pathlib
 import logging
 import tempfile
 import contextlib
-from functools import partial
+from functools import partial, wraps
 from typing import Optional, ByteString, NamedTuple
 
 from .util.swig import Wrapper
@@ -105,7 +105,7 @@ def temp_fapi_config(config):
 
 class FAPIMetaClass(BaseContextMetaClass):
     PREFIX = "Fapi_"
-    NO_PASS_CTXP = set(["Fapi_Initialize", "Fapi_Finalize"])
+    NO_PASS_CTXP = set(["Fapi_Initialize", "Fapi_Finalize", "Fapi_Free"])
 
 
 class FAPI(Wrapper, metaclass=FAPIMetaClass):
